diff src/share/vm/code/nmethod.cpp @ 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents 0654ee04b214
children 5857923e563c
line wrap: on
line diff
--- a/src/share/vm/code/nmethod.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/nmethod.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -818,8 +818,8 @@
     // Exception handler and deopt handler are in the stub section
     assert(offsets->value(CodeOffsets::Exceptions) != -1, "must be set");
     assert(offsets->value(CodeOffsets::Deopt     ) != -1, "must be set");
-    if (UseC1X) {
-      // c1x produces no (!) stub section
+    if (UseGraal) {
+      // graal produces no (!) stub section
       _exception_offset        = code_offset()          + offsets->value(CodeOffsets::Exceptions);
       _deoptimize_offset       = code_offset()          + offsets->value(CodeOffsets::Deopt);
       if (offsets->value(CodeOffsets::DeoptMH) != -1) {
@@ -2301,7 +2301,7 @@
         // information in a table.
         break;
     }
-    assert(UseC1X || stub == NULL || stub_contains(stub), "static call stub outside stub section");
+    assert(UseGraal || stub == NULL || stub_contains(stub), "static call stub outside stub section");
   }
 }